@@ -308,18 +308,60 @@ namespace Tomboy
 		{
 			string [] authors = new string [] {
 				Catalog.GetString ("Primary Development:"),
-				"\tAlex Graveley <alex@beatniksoftware.com>",
-				"\tBoyd Timothy <btimothy@gmail.com>",
-				"\tSandy Armstrong <sanfordarmstrong@gmail.com>",
+				"\tAlex Graveley (original author)",
+				"\tBoyd Timothy (retired maintainer)",
+				"\tSandy Armstrong (maintainer)",
+				"\t\t<sanfordarmstrong@gmail.com>",
 				"",
 				Catalog.GetString ("Contributors:"),
-				"\tBenjamin Podszun <benjamin.podszun@gmail.com>",
-				"\tChris Scobell <chris@thescobells.com>",
-				"\tDavid Trowbridge <trowbrds@gmail.com>",
-				"\tKevin Kubasik <kevin@kubasik.net>",
-				"\tRyan Lortie <desrt@desrt.ca>",
-				"\tSebastian Rittau <srittau@jroger.in-berlin.de>",
-				"\tStefan Schweizer <steve.schweizer@gmail.com>"
+				"\tAaron Bockover",
+				"\tAlexey Nedilko",
+				"\tAlex Kloss",
+				"\tAnders Petersson",
+				"\tAndrew Fister",
+				"\tBenjamin Podszun",
+				"\tBuchner Johannes",
+				"\tChris Scobell",
+				"\tDave Foster",
+				"\tDavid Trowbridge",
+				"\tDoug Johnston",
+				"\tEveraldo Canuto",
+				"\tFrederic Crozat",
+				"\tGabriel de Perthuis",
+				"\tJakub Steiner",
+				"\tJames Westby",
+				"\tJamin Philip Gray",
+				"\tJan Rüegg",
+				"\tJay R. Wren",
+				"\tJeffrey Stedfast",
+				"\tJeff Tickle",
+				"\tJerome Haltom",
+				"\tJoe Shaw",
+				"\tJohn Anderson",
+				"\tJohn Carr",
+				"\tJon Lund Steffensen",
+				"\tJP Rosevear",
+				"\tKevin Kubasik",
+				"\tLaurent Bedubourg",
+				"\tŁukasz Jernaś",
+				"\tMark Wakim",
+				"\tMathias Hasselmann",
+				"\tMatt Johnston",
+				"\tMike Mazur",
+				"\tNathaniel Smith",
+				"\tPrzemysław Grzegorczyk",
+				"\tRobert Buchholz",
+				"\tRobin Sonefors",
+				"\tRodrigo Moya",
+				"\tRomain Tartiere",
+				"\tRyan Lortie",
+				"\tSebastian Dröge",
+				"\tSebastian Rittau",
+				"\tStefan Cosma",
+				"\tStefan Schweizer",
+				"\tTommi Asiala",
+				"\tWouter Bolsterlee",
+				"\tYonatan Oren"
 			};
 
 			string [] documenters = new string [] {
@@ -377,7 +419,8 @@ namespace Tomboy
 		public static bool TrayIconShowing
 		{
 			get {
-				tray_icon_showing = tray_icon.IsEmbedded && tray_icon.Visible;
+				tray_icon_showing = !is_panel_applet && tray_icon != null &&
+					tray_icon.IsEmbedded && tray_icon.Visible;
 				return tray_icon_showing;
 			}
 		}
